%define major          2.2
%define libname_qt5    %mklibname %{name} %{major}
%define libdevname_qt5 %mklibname %{name} -d

%define libname_qt6    %mklibname %{name}-qt6_ %{major}
%define libdevname_qt6 %mklibname %{name}-qt6 -d

%bcond_without  qt5
%bcond_without  qt6

Name:           kddockwidgets
Version:        2.2.5
Release:        %mkrel 1
Summary:        Qt dock widget library, suitable for replacing QDockWidget
Group:          System/Libraries
License:        GPL-2.0-only OR GPL-3.0-only
URL:            https://www.kdab.com/development-resources/qt-tools/kddockwidgets
Source:         https://github.com/KDAB/KDDockWidgets/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/KDAB/KDDockWidgets/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc

### Qt5 build dependencies
%if %{with qt5}
BuildRequires:  cmake(Qt5Core) >= 5.15
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
%endif
### Qt6 build dependencies
%if %{with qt6}
BuildRequires:  cmake(Qt6Core) >= 6.2
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Widgets)
%endif

%description
KDDockWidgets is a Qt dock widget library written by KDAB, suitable for
replacing QDockWidget and implementing advanced functionalities missing in Qt.

Although KDDockWidgets is ready to be used out of the box, it can also be seen
as a framework to allow building very tailored custom docking systems. It tries
to expose every internal widget and every knob for the app developer to tune.

#--------------------------------------------------------------
### Qt5 ###
%if %{with qt5}

%package -n     %{libname_qt5}
Summary:        Qt5 dock widget library, suitable for replacing QDockWidget
Group:          System/Libraries

%description -n %{libname_qt5}
KDDockWidgets is a Qt dock widget library written by KDAB, suitable for
replacing QDockWidget and implementing advanced functionalities missing in Qt.

Although KDDockWidgets is ready to be used out of the box, it can also be seen
as a framework to allow building very tailored custom docking systems. It tries
to expose every internal widget and every knob for the app developer to tune.

%files -n %{libname_qt5}
%license LICENSES/*
%doc README.md
%{_qt5_libdir}/libkddockwidgets.so.%{major}{,.*}

#--------------------------------------------------------------

%package -n     %{libdevname_qt5}
Summary:        Development files for libkddockwidgets (Qt5)
Group:          Development/KDE and Qt
Requires:       %{libname_qt5} = %{version}-%{release}
Provides:       %{name}-qt5-devel = %{version}-%{release}

%description -n %{libdevname_qt5}
This packages contains the libraries, include and other files
you can use to develop applications with KDDockWidgets for Qt5.

%files -n %{libdevname_qt5}
%license LICENSES/*
%doc README.md
%{_includedir}/kddockwidgets/
%{_qt5_libdir}/cmake/KDDockWidgets/
%{_qt5_libdir}/libkddockwidgets.so
%{_qt5_archdatadir}/mkspecs/modules/qt_KDDockWidgets.pri

%endif
#--------------------------------------------------------------
### Qt6 ###
%if %{with qt6}

%package -n     %{libname_qt6}
Summary:        Qt6 dock widget library, suitable for replacing QDockWidget
Group:          System/Libraries

%description -n %{libname_qt6}
KDDockWidgets is a Qt dock widget library written by KDAB, suitable for
replacing QDockWidget and implementing advanced functionalities missing in Qt.

Although KDDockWidgets is ready to be used out of the box, it can also be seen
as a framework to allow building very tailored custom docking systems. It tries
to expose every internal widget and every knob for the app developer to tune.

%files -n %{libname_qt6}
%license LICENSES/*
%doc README.md
%{_qt6_libdir}/libkddockwidgets-qt6.so.%{major}{,.*}

#--------------------------------------------------------------

%package -n     %{libdevname_qt6}
Summary:        Development files for libkddockwidgets (Qt6)
Group:          Development/KDE and Qt
Requires:       %{libname_qt6} = %{version}-%{release}
Provides:       %{name}-qt6-devel = %{version}-%{release}

%description -n %{libdevname_qt6}
This packages contains the libraries, include and other files
you can use to develop applications with KDDockWidgets for Qt6.

%files -n %{libdevname_qt6}
%license LICENSES/*
%doc README.md
%{_includedir}/kddockwidgets-qt6/
%{_qt6_libdir}/cmake/KDDockWidgets-qt6/
%{_qt6_libdir}/libkddockwidgets-qt6.so
%{_qt6_mkspecsdir}/modules/qt_KDDockWidgets.pri

%endif
#--------------------------------------------------------------

%prep
%autosetup -p1 -n KDDockWidgets-%{version}

%build
### Build Qt5 ###
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake_qt5
%cmake_build
%endif

### Build Qt6 ###
%if %{with qt6}
%define _vpath_builddir build-qt6
%cmake_qt6 -DKDDockWidgets_QT6:BOOL=ON
%cmake_build
%endif

%install
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake_install
%endif

%if %{with qt6}
%define _vpath_builddir build-qt6
%cmake_install
%endif

# Installed using %%doc and %%license instead
rm -r %{buildroot}%{_datadir}/doc


%changelog
* Wed Jul 16 2025 daviddavid <daviddavid> 2.2.5-1.mga10
+ Revision: 2256597
- new version: 2.2.5

* Tue Jul 01 2025 umeabot <umeabot> 2.2.1-2.mga10
+ Revision: 2235535
- Mageia 10 Mass Rebuild

* Tue Feb 04 2025 daviddavid <daviddavid> 2.2.1-1.mga10
+ Revision: 2145159
- new version: 2.2.1
- now libmajor is 2.2

* Thu Nov 02 2023 daviddavid <daviddavid> 1.7.0-1.mga10
+ Revision: 2003502
- new version: 1.7.0
- now libmajor is 1.7

* Thu Mar 23 2023 daviddavid <daviddavid> 1.6.0-1.mga9
+ Revision: 1950146
- initial package kddockwidgets (new dependency for hotspot)

